@tannerlinsley: Migrating asap.
Summary
Aiden Bai releases cnfast, a drop-in replacement for the cn utility that is 3x faster, and Tanner Linsley announces migrating to it.
View Cached Full Text
Cached at: 06/22/26, 01:45 PM
Migrating asap.
Aiden Bai (@aidenybai): Introducing cnfast
A 3x faster drop-in replacement for
cnnpx cnfast migrate
Similar Articles
@charliermarsh: I've been contributing to cargo-fixit: a much faster, drop-in replacement for `clippy --fix`. Here's an extreme exampleβ¦
Charlie Marsh announces cargo-fixit, a faster drop-in replacement for clippy --fix, showing a 120x speedup on the Codex repo.
@nickoates_: just switched @aisdk from ππππ (esbuild) to πππππ π (rolldown). faster and smaller builds!
Vercel's AI SDK (aisdk) has switched its build toolchain from tsup (esbuild-based) to tsdown (rolldown-based), reporting faster and smaller builds.
@thsottiaux: Day 3 (encore)/ We silently re-shipped codex cloud. Itβs pretty good now
Tailscale announced a quiet re-ship of Codex Cloud, which can now securely connect to resources on a user's tailnet. The update emphasizes making tools easy to combine for greater utility.
@almoggavra: this is now deployed at Dropbox and their SlateDB startup time dropped 60x LIST calls are expensive, folk
Almog Gavra announces that a performance optimization using HEAD requests instead of LIST calls has been deployed at Dropbox, reducing SlateDB startup time by 60x.
@rauchg: Faster
fx v0.0.12 released with up to 560x faster session listing, instant resume of large session stores, improved GitHub-flavored Markdown, and better MCP reliability.